@@ -285,7 +285,7 @@ mod test {
     #[test]
     fn to_date() {
         test! {
-            let x: Robj = r!([18990.0, 18991.0]).set_class(&["Date"]).unwrap();
+            let x: Robj = r!([18990.0, 18991.0]).set_class(&["Date"]).unwrap().clone();
             assert_eq!(rdate::robj2date(x, "x").unwrap(), [Some(NaiveDate::from_ymd_opt(2021, 12, 29).unwrap()), Some(NaiveDate::from_ymd_opt(2021, 12, 30).unwrap())]);
         }
     }
