@@ -1,9 +1,17 @@
 test_that("period_begin returns right begining date", {
 
   dates <- seq.Date(from = as.Date("2016-03-07") - 1, to = as.Date("2016-03-13") + 1, by = "1 day")
-  out <- period_begin(dates, unit = "week") == as.Date("2016-03-07")
+
+  # check both integer dates and double dates
+  dates_int <- structure(as.integer(dates), class = "Date")
+  out <- period_begin(dates_int, unit = "week") == as.Date("2016-03-07")
   expect_equal(out, c(FALSE, rep(TRUE, length(out) - 2L), FALSE))
 
+  dates_dbl <- structure(as.numeric(dates), class = "Date")
+  out <- period_begin(dates_dbl, unit = "week") == as.Date("2016-03-07")
+  expect_equal(out, c(FALSE, rep(TRUE, length(out) - 2L), FALSE))
+
+  # other checks: such as month, quarter, year
   dates <- seq.Date(from = as.Date("2015-01-01") - 1, to = as.Date("2015-01-31") + 1, by = "1 day")
   out <- period_begin(dates, unit = "month") == as.Date("2015-01-01")
   expect_equal(out, c(FALSE, rep(TRUE, length(out) - 2L), FALSE))
